package model;

import java.awt.*;
import java.util.Iterator;
import java.util.List;


/**
 * Represent a composite figure
 */
public class CompositeShape extends AbstractShape implements Iterable<Shape> {

  // Composed figures
  private List<Shape> shapes;

  /**
   * Create a composite figure from the list of figures.
   *
   * @param selectedShapes
   */
  public CompositeShape(List<Shape> selectedShapes) {
    shapes = selectedShapes;
  }

  @Override
  public void draw(Graphics g) {
    for (Shape f : shapes)
      f.draw(g);
  }

  @Override
  public boolean contains(Point point) {
    // It would be better if this implementation computed a
    // bounding rectangle for all figures and used that for
    // containment. With this implementation, contains will
    // only work for a point within one of the composed figures
    for (Shape f : shapes)
      if (f.contains(point))
        return true;
    return false;
  }

  @Override
  public void translate(int dx, int dy) {
    for (Shape f : shapes)
      f.translate(dx, dy);
  }

  @Override
  public void select() {
    super.select();
    for (Shape f : shapes)
      f.select();
  }

  @Override
  public void unselect() {
    super.unselect();
    for (Shape f : shapes)
      f.unselect();
  }

  @Override
  public Iterator<Shape> iterator() {
    return shapes.iterator();
  }
}
